<?php
/**
 * The admin-specific functionality of the plugin.
 *
 * Loads and defines the admin area setting files for this plugin
 *
 * @since      1.0.0
 * @package    Fp_Fel
 * @subpackage Fp_Fel/includes
 * @author     Futureprofilez <info@futureprofilez.com>
 */

class Fp_Fel_Admin {

    /**
     * The ID of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string    $plugin_name    The ID of this plugin.
     */
    private $plugin_name;

    /**
     * The version of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string    $version    The current version of this plugin.
     */
    private $version;

    /**
     * Initialize the class and set its properties.
     *
     * @since    1.0.0
     * @param      string    $plugin_name       The name of this plugin.
     * @param      string    $version    The version of this plugin.
     */
    public function __construct( $plugin_name, $version ) {

        $this->plugin_name = $plugin_name;
        $this->version = $version;
        $this->Fp_Fel_options = get_option($this->plugin_name);

    }

    /**
     * Register the administration menu for this plugin into the WordPress Dashboard menu.
     *
     * @since    1.0.0
     */
    public function add_plugin_admin_menu() {

        /*
         * Add a settings page for this plugin to the Settings menu.
         *
         * NOTE:  Alternative menu locations are available via WordPress administration menu functions.
         *
         * Administration Menus: http://codex.wordpress.org/Administration_Menus
         *
         */
        $plugin_screen_hook_suffix = add_options_page( __('FP Front End Login Setup', $this->plugin_name ), 'FP Front End Login', 'manage_options', 'fp-fel', array($this, 'display_plugin_setup_page')
        );
    }
	

    /**
     * Options page callback
     */

    public function display_plugin_setup_page()
    {
        $this->options = get_option( 'fpfel_settings' );
     ?>
        <div class="wrap">
            <h1><?php _e(' Fp Front End Login',' fp-front-end-login-form');?></h1>
            <form method="post" action="options.php">
            <?php
                // This prints out all hidden setting fields
                settings_fields( 'fpfel_settings' );
                do_settings_sections( 'fp_fel' );
                submit_button();
            ?>
            </form>
        </div>
        <?php
    }

    /**
     * Register and add settings
     */

    public function page_option_init()
    {        
        register_setting(
            'fpfel_settings', // Option group
            'fpfel_settings', // Option name
            array( $this, 'sanitize_options' ) // Sanitize
        );

        add_settings_section(
            'setting_fpfel_section_id', // ID
            __('General Settings',' fp-front-end-login-form'), // Title
            array( $this, 'print_settingsection_info' ), // Callback
            'fp_fel' // Page
        );  

        add_settings_field(
            'fpfel_label_status', 
            __('Label :',' fp-front-end-login-form'), 
            array( $this, 'label_status_callback' ), 
            'fp_fel', 
            'setting_fpfel_section_id'
        ); 

        add_settings_field(
            'fpfel_login_redirect', 
            __('Successful Login Redirection :',' fp-front-end-login-form'), 
            array( $this, 'login_redirect_callback' ), 
            'fp_fel', 
            'setting_fpfel_section_id'
        );    

    }

    /**
     * Sanitize each setting field as needed
     *
     * @param array $input Contains all settings fields as array keys
     */
    public function sanitize_options( $input )
    {
        $setting_fields = array(); 
        
        if( isset( $input['fpfel_label_status'] ) )
            $setting_fields['fpfel_label_status'] = sanitize_text_field( $input['fpfel_label_status'] );

        if( isset( $input['fpfel_login_redirect'] ) )
            $setting_fields['fpfel_login_redirect'] = sanitize_text_field( $input['fpfel_login_redirect'] );

        return $setting_fields;
    }
	
	
	/** 
     * Print the Section text
     */
    public function print_settingsection_info()
    {
       _e('Use <strong>[fp_login_form]</strong> shortcode or <strong>Fp Front End Login Widget</strong> to display login form on site.',' fp-front-end-login-form');
    }
 
    /** 
     * Get the settings option array and print one of its values
     */
    public function label_status_callback()
    {
     printf(
            '<input type="checkbox" id="fpfel_label_status" name="fpfel_settings[fpfel_label_status]" 
             value="active" %s /><span>(Check to show lable.)</span> ', isset( $this->options['fpfel_label_status'] ) && $this->options['fpfel_label_status']=='active'  ? ' checked="checked"': '');
      
    }

    public function login_redirect_callback()
    {  $pages = get_pages( array( 'sort_column' => 'post_date', 'sort_order' => 'desc','post_redirect'=>'publish' ) );
	   $option="";
			   foreach ( $pages as $page ) {
			   	if($this->options['fpfel_login_redirect']==$page->ID){
						$option .= '<option selected value="' .$page->ID. '">';
				}else{
						$option .= '<option value="' .$page->ID. '">';
				}
						$option .= $page->post_title;
						$option .= '</option>';
						 }
        printf(
        ' <Select class="fpfel_option" name="fpfel_settings[fpfel_login_redirect]"><option value="current">Select Page</option>'.__($option).'</select>'
        );
    }

    /**
     * Add settings action link to the plugins page.
     *
     * @since    1.0.0
     */
    public function add_action_links( $links ) {

        return array_merge(
            array(
                'settings' => '<a href="' . admin_url( 'options-general.php?page=fp-fel') . '">' . __( 'Settings', $this->plugin_name ) . '</a>'
            ),
            $links
        );

    }

}
 
?>