<?php
/**
 * Create front end login form.
 *
 * This file defines all code necessary to create login form shortcode.
 * @link       http://futureprofilez.com/
 * @since      1.0.0
 * @since      1.0.0
 * @package    fp-front-end-login
 * @subpackage fp-front-end-login/includes
 * @author     Futureprofilez <info@futureprofilez.com>
 */
 
function LoginForm($atts) {
 	if(!is_user_logged_in()) {
		 	
		 $output = login_form_fields();
	 
	} else {
		// could show some logged in user info here
		 $current_user=wp_get_current_user();
		 $output  = '<div class="user_info"> ';
		 $output .= '<span>'._e('User Info:', 'fp-front-end-login-form').'</span>' . $current_user->user_login .__(' You are already signed in. Click below link to sign out.', 'fp-front-end-login-form').'<br/>';
	     $output .= '<a href="'.wp_logout_url( get_permalink()).'" title="Logout">'.__('Logout', 'fp-front-end-login-form').'</a></div>';
		
	}
	return $output;	
}

add_shortcode('fp_login_form', 'LoginForm');

// login form fields
function login_form_fields() {
  ob_start();	 
?>
   <?php $labelclass = "";
         $fpfel_settings = get_option( 'fpfel_settings' ); 
	     if(isset($fpfel_settings['fpfel_label_status'])  && $fpfel_settings['fpfel_label_status']=='active'){
	  	 $labelclass = "labelshow";
	     }else{
	  	 $labelclass = "labelhide";
	     }
    ?>
  <form id="login_form"  class="login_form" action="" method="post">
	 <h4><?php _e('Login', 'fp-front-end-login-form'); ?></h4>
	 <?php show_error_messages();  // show any error messages after form submission ?>
	 <div class="form-group">
	 	<label for="username" class="<?php echo $labelclass; ?>"><?php _e( 'Username or email address :', 'fp-front-end-login-form' ); ?></label> 
		<input name="user_login" id="user_login" placeholder="<?php _e( 'Enter Username', 'fp-front-end-login-form' ); ?>" class="form-control required" type="text"/>
		<p id="login_username"></p>
	 </div>
	 <div class="form-group">
	   <label for="password" class="<?php echo $labelclass; ?>"><?php _e( 'Password :', 'fp-front-end-login-form' ); ?></label> 
	   <input name="user_pass" id="user_pass" placeholder="<?php _e( 'Enter Password', 'fp-front-end-login-form' ); ?>" class="form-control required" type="password"/>
	   <p id="login_password"></p>
	 </div>
	 <input type="hidden" name="login_nonce" value="<?php echo wp_create_nonce('fp-login-nonce'); ?>"/>
     <div class="form-group">
     	<?php 
     	  $lostargs = array( 'action' => 'lostpassword' );
          $regargs = array( 'action' => 'register' );
		  $userscanreg = get_option('users_can_register');
     	?>
	    <a class="forget_pass"href="<?php echo add_query_arg( $lostargs, network_site_url('wp-login.php', 'login')); ?>"><?php _e('Forgot your password ?', 'fp-front-end-login-form'); ?></a> 
    	<?php if($userscanreg==1){ ?>
    	| <a class="forget_pass"href="<?php echo add_query_arg( $regargs, network_site_url('wp-login.php', 'login')); ?>"><?php _e('Register', 'fp-front-end-login-form'); ?></a>
        <?php } ?>
     </div>
	<div class="clearfix"></div>
	<input id="login_submit" class="btn btn-default login_btn" type="submit" value="Login"/>
 </form>
		 

<?php
 return ob_get_clean();
}

// logs a member  after submitting login  form
function login_member() {
	global $wpdb;
	if(isset($_POST['user_login']) && wp_verify_nonce($_POST['login_nonce'], 'fp-login-nonce')) {
	
	// this returns the user ID and other info from the user name
	$login = trim($_POST['user_login']);
	$password =$_POST['user_pass'];
	if (filter_var($login, FILTER_VALIDATE_EMAIL)) { //Invalid Email
	  $user = get_user_by('email', $login);
	  } else {
	  $user = get_user_by('login', $login);
	  }

	// if the user name doesn't exist
	if(!$user) {
		
	errors()->add('empty_username', __('Please enter valid username or email-id.', 'fp-front-end-login-form'));
	}
	
	// check the user's login with their password
	if( $user && !wp_check_password($password, $user->user_pass, $user->ID)) {
		
	errors()->add('empty_password', __('Please enter valid password.', 'fp-front-end-login-form'));
	}
	
	// if no password was entered
	if(!isset($password) ||$password == '') {
	
	errors()->add('empty_password', __('Please enter valid password.', 'fp-front-end-login-form'));
	}
	
	// retrieve all error messages
	$errors = errors()->get_error_messages();
	
	// only log the user in if there are no errors
	if(empty($errors)) {
       $secure = ( 'https' === parse_url( wp_login_url(), PHP_URL_SCHEME ) );
 	   $secure_cookie=wp_set_auth_cookie( $user->ID, false, $secure );
  
	   $creds = array('user_login' => $user->data->user_login, 'user_password' => $password);
       $user = wp_signon( $creds, $secure_cookie );
       wp_set_current_user($user->ID, $login);
	   $fpfel_settings = get_option( 'fpfel_settings' ); 
	   
	   if(isset($fpfel_settings['fpfel_login_redirect']) && $fpfel_settings['fpfel_login_redirect']!='current'){
	     $redirection = get_permalink( $fpfel_settings['fpfel_login_redirect']);
	   }else{
	  	 $redirection = get_site_url();
	   }
	   wp_redirect($redirection); exit;
	
	}
	
	}
}
add_action('init', 'login_member');

// used for tracking error messages
function errors(){
	static $wp_error; // Will hold global variable safely
	return isset($wp_error) ? $wp_error : ($wp_error = new WP_Error(null, null, null));
}

// displays error messages from form submissions
function show_error_messages() {
if($codes = errors()->get_error_codes()) {
	echo '<div class="errors">';
   // Loop error codes and display errors
	foreach($codes as $code){
	$message = errors()->get_error_message($code);
	echo '<span class="error"><strong>' . __('Error', 'fp-front-end-login-form') . '</strong>: ' . $message . '</span><br/>';
	}
	echo '</div>';
	}
}
?>